==> qingcloud-cli-1.0.9.tar.gz: qingcloud-cli-1.0.9/qingcloud/cli/iaas_client/actions/router/__init__.py <==
# =========================================================================
# Copyright 2012-present Yunify, Inc.
# -------------------------------------------------------------------------
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this work except in compliance with the License.
# You may obtain a copy of the License in the LICENSE file, or at:
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =========================================================================

from .add_router_statics import AddRouterStaticsAction
from .create_routers import CreateRoutersAction
from .delete_router_statics import DeleteRouterStaticsAction
from .delete_routers import DeleteRoutersAction
from .describe_router_statics import DescribeRouterStaticsAction
from .describe_router_vxnets import DescribeRouterVxnetsAction
from .describe_routers import DescribeRoutersAction
from .join_router import JoinRouterAction
from .leave_router import LeaveRouterAction
from .modify_router_attributes import ModifyRouterAttributesAction
from .modify_router_static_attributes import ModifyRouterStaticAttributesAction
from .poweroff_routers import PowerOffRoutersAction
from .poweron_routers import PowerOnRoutersAction
from .update_routers import UpdateRoutersAction

__all__ = [AddRouterStaticsAction, CreateRoutersAction, DeleteRouterStaticsAction,
        DeleteRoutersAction, DescribeRouterStaticsAction,
        DescribeRouterVxnetsAction, DescribeRoutersAction,
        JoinRouterAction, LeaveRouterAction, ModifyRouterAttributesAction,
        ModifyRouterStaticAttributesAction, PowerOffRoutersAction,
        PowerOnRoutersAction, UpdateRoutersAction]

==> qingcloud-cli-1.1.0.tar.gz: qingcloud-cli-1.1.0/qingcloud/cli/iaas_client/actions/router/__init__.py <==
# =========================================================================
# Copyright 2012-present Yunify, Inc.
# -------------------------------------------------------------------------
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this work except in compliance with the License.
# You may obtain a copy of the License in the LICENSE file, or at:
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =========================================================================

from .add_router_statics import AddRouterStaticsAction
from .add_router_static_entries import AddRouterStaticEntriesAction
from .create_routers import CreateRoutersAction
from .delete_router_statics import DeleteRouterStaticsAction
from .delete_router_static_entries import DeleteRouterStaticEntriesAction
from .delete_routers import DeleteRoutersAction
from .describe_router_statics import DescribeRouterStaticsAction
from .describe_router_static_entries import DescribeRouterStaticEntriesAction
from .describe_router_vxnets import DescribeRouterVxnetsAction
from .describe_routers import DescribeRoutersAction
from .join_router import JoinRouterAction
from .leave_router import LeaveRouterAction
from .modify_router_attributes import ModifyRouterAttributesAction
from .modify_router_static_attributes import ModifyRouterStaticAttributesAction
from .modify_router_static_entry_attributes import ModifyRouterStaticEntryAttributesAction
from .poweroff_routers import PowerOffRoutersAction
from .poweron_routers import PowerOnRoutersAction
from .update_routers import UpdateRoutersAction

__all__ = [
    AddRouterStaticsAction,
    AddRouterStaticEntriesAction,
    CreateRoutersAction,
    DeleteRouterStaticsAction,
    DeleteRouterStaticEntriesAction, 
    DeleteRoutersAction,
    DescribeRouterStaticsAction,
    DescribeRouterStaticEntriesAction,
    DescribeRouterVxnetsAction,
    DescribeRoutersAction,
    JoinRouterAction,
    LeaveRouterAction,
    ModifyRouterAttributesAction,
    ModifyRouterStaticAttributesAction,
    ModifyRouterStaticEntryAttributesAction,
    PowerOffRoutersAction,
    PowerOnRoutersAction,
    UpdateRoutersAction,
]
